==> qmmp_0.4.3.orig.tar.gz: qmmp-0.4.3/src/plugins/Input/cue/translations/cue_plugin_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es">
<context>
    <name>DecoderCUEFactory</name>
    <message>
        <location filename="../decodercuefactory.cpp" line="44"/>
        <source>CUE Plugin</source>
        <translation>Módulo CUE</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="47"/>
        <source>CUE Files</source>
        <translation>Archivos CUE</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="85"/>
        <source>About CUE Audio Plugin</source>
        <translation>Acerca del módulo de audio CUE</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="86"/>
        <source>Qmmp CUE Audio Plugin</source>
        <translation>Módulo de audio CUE para Qmmp</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="87"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Escrito por: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>CUE Plugin Settings</source>
        <translation>Configuración del módulo CUE</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>CUE encoding</source>
        <translation>Codificación CUE</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>Automatic charset detection</source>
        <translation>Detección automática del juego de caracteres</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Language:</source>
        <translation>Lenguaje:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="65"/>
        <source>Default encoding:</source>
        <translation>Codificación predeterminada</translation>
    </message>
</context>
</TS>

==> qmmp_0.5.5.orig.tar.gz: qmmp-0.5.5/src/plugins/Input/cue/translations/cue_plugin_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es">
<context>
    <name>DecoderCUEFactory</name>
    <message>
        <location filename="../decodercuefactory.cpp" line="44"/>
        <source>CUE Plugin</source>
        <translation>Módulo CUE</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="47"/>
        <source>CUE Files</source>
        <translation>Archivos CUE</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="95"/>
        <source>About CUE Audio Plugin</source>
        <translation>Acerca del módulo de audio CUE</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="96"/>
        <source>Qmmp CUE Audio Plugin</source>
        <translation>Módulo de audio CUE para Qmmp</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="97"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Escrito por: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>CUE Plugin Settings</source>
        <translation>Configuración del módulo CUE</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Common settings</source>
        <translation>Opciones comunes</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>Automatic file detection</source>
        <translation>Detectar archivo automáticamente</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>CUE encoding</source>
        <translation>Codificación CUE</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="51"/>
        <source>Automatic charset detection</source>
        <translation>Detección automática del juego de caracteres</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <source>Language:</source>
        <translation>Lenguaje:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="81"/>
        <source>Default encoding:</source>
        <translation>Codificación predeterminada</translation>
    </message>
</context>
</TS>
